summaryrefslogtreecommitdiffstats
path: root/kmail/kmreaderwin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmreaderwin.h')
-rw-r--r--kmail/kmreaderwin.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmreaderwin.h b/kmail/kmreaderwin.h
index 32c7abdf..27bc33b0 100644
--- a/kmail/kmreaderwin.h
+++ b/kmail/kmreaderwin.h
@@ -323,7 +323,7 @@ public:
/* show or hide the list that points to the attachments */
void setShowAttachmentQuicklist( bool showAttachmentQuicklist = true ) { mShowAttachmentQuicklist = showAttachmentQuicklist; }
- // This controls whether a Toltec invitation is shown in its raw form or as a replacement text.
+ // This controls whether a Toltec invitation is shown in its raw form or as a tqreplacement text.
// This can be toggled with the "kmail:showRawToltecMail" link.
bool showRawToltecMail() const { return mShowRawToltecMail; }
void setShowRawToltecMail( bool showRawToltecMail ) { mShowRawToltecMail = showRawToltecMail; }
@@ -331,9 +331,9 @@ public:
/* retrieve BodyPartMemento of id \a which for partNode \a node */
KMail::Interface::BodyPartMemento * bodyPartMemento( const partNode * node, const TQCString & which ) const;
/* set/replace BodyPartMemento \a memento of id \a which for
partNode \a node. If there was a BodyPartMemento registered
- already, replaces (deletes) that one. */
+ already, tqreplaces (deletes) that one. */
void setBodyPartMemento( const partNode * node, const TQCString & which, KMail::Interface::BodyPartMemento * memento );
/// Scrolls to the given attachment and marks it with a yellow border
@@ -347,7 +347,7 @@ private:
signals:
/** Emitted after parsing of a message to have it stored
in unencrypted state in it's folder. */
- void replaceMsgByUnencryptedVersion();
+ void tqreplaceMsgByUnencryptedVersion();
/** The user presses the right mouse button. 'url' may be 0. */
void popupMenu(KMMessage &msg, const KURL &url, const TQPoint& mousePos);
@@ -369,7 +369,7 @@ public slots:
/** Refresh the reader window */
void updateReaderWin();
- /** HTML Widget scrollbar and layout handling. */
+ /** HTML Widget scrollbar and tqlayout handling. */
void slotScrollUp();
void slotScrollDown();
void slotScrollPrior();
@@ -420,7 +420,7 @@ public slots:
void slotMessageArrived( KMMessage *msg );
/** start IM Chat with addressee */
void slotIMChat();
- void contactStatusChanged( const TQString &uid);
+ void contacStatusChanged( const TQString &uid);
void slotLevelQuote( int l );
void slotTouchMessage();
@@ -331,9 +331,9 @@ public:
/* retrieve BodyPartMemento of id \a which for partNode \a node */
KMail::Interface::BodyPartMemento * bodyPartMemento( const partNode * node, const TQCString & which ) const;
- /* set/replace BodyPartMemento \a memento of id \a which for
+ /* set/tqreplace BodyPartMemento \a memento of id \a which for
partNode \a node. If there was a BodyPartMemento registered